@@ -223,7 +223,7 @@ class I18n {
 		}
 
 		if ($domain === null) {
-			$domain = self::$defaultDomain;
+			$domain = static::$defaultDomain;
 		}
 		if ($domain === '') {
 			throw new CakeException(__d('cake_dev', 'You cannot use "" as a domain.'));
@@ -399,7 +399,7 @@ class I18n {
 			foreach ($this->l10n->languagePath as $lang) {
 				$localeDef = $directory . $lang . DS . $this->category;
 				if (is_file($localeDef)) {
-					$definitions = self::loadLocaleDefinition($localeDef);
+					$definitions = static::loadLocaleDefinition($localeDef);
 					if ($definitions !== false) {
 						$this->_domains[$domain][$this->_lang][$this->category] = $definitions;
 						$this->_noLocale = false;
@@ -412,10 +412,10 @@ class I18n {
 					$translations = false;
 
 					if (is_file($app . '.mo')) {
-						$translations = self::loadMo($app . '.mo');
+						$translations = static::loadMo($app . '.mo');
 					}
 					if ($translations === false && is_file($app . '.po')) {
-						$translations = self::loadPo($app . '.po');
+						$translations = static::loadPo($app . '.po');
 					}
 
 					if ($translations !== false) {
@@ -430,10 +430,10 @@ class I18n {
 				$translations = false;
 
 				if (is_file($file . '.mo')) {
-					$translations = self::loadMo($file . '.mo');
+					$translations = static::loadMo($file . '.mo');
 				}
 				if ($translations === false && is_file($file . '.po')) {
-					$translations = self::loadPo($file . '.po');
+					$translations = static::loadPo($file . '.po');
 				}
 
 				if ($translations !== false) {
@@ -497,6 +497,9 @@ class I18n {
 					$msgid = substr($data, $r["offs"], $r["len"]);
 					unset($msgid_plural);
 
+					if (strpos($msgid, "\x04") !== false) {
+						list($context, $msgid) = explode("\x04", $msgid);
+					}
 					if (strpos($msgid, "\000")) {
 						list($msgid, $msgid_plural) = explode("\000", $msgid);
 					}
@@ -508,9 +511,10 @@ class I18n {
 					}
 
 					if ($msgid != '') {
-						$msgstr = array($context => $msgstr);
+						$translations[$msgid][$context] = $msgstr;
+					} else {
+						$translations[$msgid] = $msgstr;
 					}
-					$translations[$msgid] = $msgstr;
 
 					if (isset($msgid_plural)) {
 						$translations[$msgid_plural] =& $translations[$msgid];
