@@ -798,8 +798,8 @@ class Mysql extends DboSource {
 /**
  * {@inheritDoc}
  */
-	public function value($data, $column = null) {
-		$value = parent::value($data, $column);
+	public function value($data, $column = null, $null = true) {
+		$value = parent::value($data, $column, $null);
 		if (is_numeric($value) && substr($column, 0, 3) === 'set') {
 			return $this->_connection->quote($value);
 		}
