@@ -213,10 +213,10 @@ class Router {
  */
 	public static function defaultRouteClass($routeClass = null) {
 		if ($routeClass === null) {
-			return self::$_routeClass;
+			return static::$_routeClass;
 		}
 
-		self::$_routeClass = self::_validateRouteClass($routeClass);
+		static::$_routeClass = static::_validateRouteClass($routeClass);
 	}
 
 /**
@@ -243,7 +243,7 @@ class Router {
 	protected static function _setPrefixes() {
 		$routing = Configure::read('Routing');
 		if (!empty($routing['prefixes'])) {
-			self::$_prefixes = array_merge(self::$_prefixes, (array)$routing['prefixes']);
+			static::$_prefixes = array_merge(static::$_prefixes, (array)$routing['prefixes']);
 		}
 	}
 
@@ -254,7 +254,7 @@ class Router {
  * @see Router::$_namedExpressions
  */
 	public static function getNamedExpressions() {
-		return self::$_namedExpressions;
+		return static::$_namedExpressions;
 	}
 
 /**
@@ -266,9 +266,9 @@ class Router {
  */
 	public static function resourceMap($resourceMap = null) {
 		if ($resourceMap === null) {
-			return self::$_resourceMap;
+			return static::$_resourceMap;
 		}
-		self::$_resourceMap = $resourceMap;
+		static::$_resourceMap = $resourceMap;
 	}
 
 /**
@@ -342,9 +342,9 @@ class Router {
  * @throws RouterException
  */
 	public static function connect($route, $defaults = array(), $options = array()) {
-		self::$initialized = true;
+		static::$initialized = true;
 
-		foreach (self::$_prefixes as $prefix) {
+		foreach (static::$_prefixes as $prefix) {
 			if (isset($defaults[$prefix])) {
 				if ($defaults[$prefix]) {
 					$defaults['prefix'] = $prefix;
@@ -354,28 +354,28 @@ class Router {
 				break;
 			}
 		}
-		if (isset($defaults['prefix']) && !in_array($defaults['prefix'], self::$_prefixes)) {
-			self::$_prefixes[] = $defaults['prefix'];
+		if (isset($defaults['prefix']) && !in_array($defaults['prefix'], static::$_prefixes)) {
+			static::$_prefixes[] = $defaults['prefix'];
 		}
 		$defaults += array('plugin' => null);
 		if (empty($options['action'])) {
 			$defaults += array('action' => 'index');
 		}
-		$routeClass = self::$_routeClass;
+		$routeClass = static::$_routeClass;
 		if (isset($options['routeClass'])) {
 			if (strpos($options['routeClass'], '.') === false) {
 				$routeClass = $options['routeClass'];
 			} else {
 				list(, $routeClass) = pluginSplit($options['routeClass'], true);
 			}
-			$routeClass = self::_validateRouteClass($routeClass);
+			$routeClass = static::_validateRouteClass($routeClass);
 			unset($options['routeClass']);
 		}
 		if ($routeClass === 'RedirectRoute' && isset($defaults['redirect'])) {
 			$defaults = $defaults['redirect'];
 		}
-		self::$routes[] = new $routeClass($route, $defaults, $options);
-		return self::$routes;
+		static::$routes[] = new $routeClass($route, $defaults, $options);
+		return static::$routes;
 	}
 
 /**
@@ -416,7 +416,7 @@ class Router {
 		if (is_string($url)) {
 			$url = array('redirect' => $url);
 		}
-		return self::connect($route, $url, $options);
+		return static::connect($route, $url, $options);
 	}
 
 /**
@@ -473,7 +473,7 @@ class Router {
  */
 	public static function connectNamed($named, $options = array()) {
 		if (isset($options['separator'])) {
-			self::$_namedConfig['separator'] = $options['separator'];
+			static::$_namedConfig['separator'] = $options['separator'];
 			unset($options['separator']);
 		}
 
@@ -484,23 +484,23 @@ class Router {
 			$options += array('default' => false, 'reset' => false, 'greedy' => true);
 		}
 
-		if ($options['reset'] || self::$_namedConfig['rules'] === false) {
-			self::$_namedConfig['rules'] = array();
+		if ($options['reset'] || static::$_namedConfig['rules'] === false) {
+			static::$_namedConfig['rules'] = array();
 		}
 
 		if ($options['default']) {
-			$named = array_merge($named, self::$_namedConfig['default']);
+			$named = array_merge($named, static::$_namedConfig['default']);
 		}
 
 		foreach ($named as $key => $val) {
 			if (is_numeric($key)) {
-				self::$_namedConfig['rules'][$val] = true;
+				static::$_namedConfig['rules'][$val] = true;
 			} else {
-				self::$_namedConfig['rules'][$key] = $val;
+				static::$_namedConfig['rules'][$key] = $val;
 			}
 		}
-		self::$_namedConfig['greedyNamed'] = $options['greedy'];
-		return self::$_namedConfig;
+		static::$_namedConfig['greedyNamed'] = $options['greedy'];
+		return static::$_namedConfig;
 	}
 
 /**
@@ -510,7 +510,7 @@ class Router {
  * @see Router::$_namedConfig
  */
 	public static function namedConfig() {
-		return self::$_namedConfig;
+		return static::$_namedConfig;
 	}
 
 /**
@@ -533,7 +533,7 @@ class Router {
 		$options += array(
 			'connectOptions' => array(),
 			'prefix' => '/',
-			'id' => self::ID . '|' . self::UUID
+			'id' => static::ID . '|' . static::UUID
 		);
 
 		$prefix = $options['prefix'];
@@ -554,7 +554,7 @@ class Router {
 				$prefix = '/' . $plugin . '/';
 			}
 
-			foreach (self::$_resourceMap as $params) {
+			foreach (static::$_resourceMap as $params) {
 				$url = $prefix . $urlName . (($params['id']) ? '/:id' : '');
 
 				Router::connect($url,
@@ -570,9 +570,9 @@ class Router {
 					)
 				);
 			}
-			self::$_resourceMapped[] = $urlName;
+			static::$_resourceMapped[] = $urlName;
 		}
-		return self::$_resourceMapped;
+		return static::$_resourceMapped;
 	}
 
 /**
@@ -581,7 +581,7 @@ class Router {
  * @return array A list of prefixes used in connected routes
  */
 	public static function prefixes() {
-		return self::$_prefixes;
+		return static::$_prefixes;
 	}
 
 /**
@@ -591,8 +591,8 @@ class Router {
  * @return array Parsed elements from URL
  */
 	public static function parse($url) {
-		if (!self::$initialized) {
-			self::_loadRoutes();
+		if (!static::$initialized) {
+			static::_loadRoutes();
 		}
 
 		$ext = null;
@@ -606,11 +606,11 @@ class Router {
 			parse_str($queryParameters, $queryParameters);
 		}
 
-		extract(self::_parseExtension($url));
+		extract(static::_parseExtension($url));
 
-		foreach (self::$routes as $route) {
+		foreach (static::$routes as $route) {
 			if (($r = $route->parse($url)) !== false) {
-				self::$_currentRoute[] = $route;
+				static::$_currentRoute[] = $route;
 				$out = $r;
 				break;
 			}
@@ -638,14 +638,14 @@ class Router {
 	protected static function _parseExtension($url) {
 		$ext = null;
 
-		if (self::$_parseExtensions) {
+		if (static::$_parseExtensions) {
 			if (preg_match('/\.[0-9a-zA-Z]*$/', $url, $match) === 1) {
 				$match = substr($match[0], 1);
-				if (empty(self::$_validExtensions)) {
+				if (empty(static::$_validExtensions)) {
 					$url = substr($url, 0, strpos($url, '.' . $match));
 					$ext = $match;
 				} else {
-					foreach (self::$_validExtensions as $name) {
+					foreach (static::$_validExtensions as $name) {
 						if (strcasecmp($name, $match) === 0) {
 							$url = substr($url, 0, strpos($url, '.' . $name));
 							$ext = $match;
@@ -674,13 +674,13 @@ class Router {
  */
 	public static function setRequestInfo($request) {
 		if ($request instanceof CakeRequest) {
-			self::$_requests[] = $request;
+			static::$_requests[] = $request;
 		} else {
 			$requestObj = new CakeRequest();
 			$request += array(array(), array());
 			$request[0] += array('controller' => false, 'action' => false, 'plugin' => null);
 			$requestObj->addParams($request[0])->addPaths($request[1]);
-			self::$_requests[] = $requestObj;
+			static::$_requests[] = $requestObj;
 		}
 	}
 
@@ -692,7 +692,7 @@ class Router {
  * @see Object::requestAction()
  */
 	public static function popRequest() {
-		return array_pop(self::$_requests);
+		return array_pop(static::$_requests);
 	}
 
 /**
@@ -703,10 +703,10 @@ class Router {
  */
 	public static function getRequest($current = false) {
 		if ($current) {
-			$i = count(self::$_requests) - 1;
-			return isset(self::$_requests[$i]) ? self::$_requests[$i] : null;
+			$i = count(static::$_requests) - 1;
+			return isset(static::$_requests[$i]) ? static::$_requests[$i] : null;
 		}
-		return isset(self::$_requests[0]) ? self::$_requests[0] : null;
+		return isset(static::$_requests[0]) ? static::$_requests[0] : null;
 	}
 
 /**
@@ -716,11 +716,11 @@ class Router {
  * @return array Parameter information
  */
 	public static function getParams($current = false) {
-		if ($current && self::$_requests) {
-			return self::$_requests[count(self::$_requests) - 1]->params;
+		if ($current && static::$_requests) {
+			return static::$_requests[count(static::$_requests) - 1]->params;
 		}
-		if (isset(self::$_requests[0])) {
-			return self::$_requests[0]->params;
+		if (isset(static::$_requests[0])) {
+			return static::$_requests[0]->params;
 		}
 		return array();
 	}
@@ -748,12 +748,12 @@ class Router {
  */
 	public static function getPaths($current = false) {
 		if ($current) {
-			return self::$_requests[count(self::$_requests) - 1];
+			return static::$_requests[count(static::$_requests) - 1];
 		}
-		if (!isset(self::$_requests[0])) {
+		if (!isset(static::$_requests[0])) {
 			return array('base' => null);
 		}
-		return array('base' => self::$_requests[0]->base);
+		return array('base' => static::$_requests[0]->base);
 	}
 
 /**
@@ -763,17 +763,17 @@ class Router {
  * @return void
  */
 	public static function reload() {
-		if (empty(self::$_initialState)) {
-			self::$_initialState = get_class_vars('Router');
-			self::_setPrefixes();
+		if (empty(static::$_initialState)) {
+			static::$_initialState = get_class_vars('Router');
+			static::_setPrefixes();
 			return;
 		}
-		foreach (self::$_initialState as $key => $val) {
+		foreach (static::$_initialState as $key => $val) {
 			if ($key !== '_initialState') {
-				self::${$key} = $val;
+				static::${$key} = $val;
 			}
 		}
-		self::_setPrefixes();
+		static::_setPrefixes();
 	}
 
 /**
@@ -785,14 +785,14 @@ class Router {
  */
 	public static function promote($which = null) {
 		if ($which === null) {
-			$which = count(self::$routes) - 1;
+			$which = count(static::$routes) - 1;
 		}
-		if (!isset(self::$routes[$which])) {
+		if (!isset(static::$routes[$which])) {
 			return false;
 		}
-		$route =& self::$routes[$which];
-		unset(self::$routes[$which]);
-		array_unshift(self::$routes, $route);
+		$route =& static::$routes[$which];
+		unset(static::$routes[$which]);
+		array_unshift(static::$routes, $route);
 		return true;
 	}
 
@@ -826,8 +826,8 @@ class Router {
  * @return string Full translated URL with base path.
  */
 	public static function url($url = null, $full = false) {
-		if (!self::$initialized) {
-			self::_loadRoutes();
+		if (!static::$initialized) {
+			static::_loadRoutes();
 		}
 
 		$params = array('plugin' => null, 'controller' => null, 'action' => 'index');
@@ -839,8 +839,8 @@ class Router {
 		}
 
 		$path = array('base' => null);
-		if (!empty(self::$_requests)) {
-			$request = self::$_requests[count(self::$_requests) - 1];
+		if (!empty(static::$_requests)) {
+			$request = static::$_requests[count(static::$_requests) - 1];
 			$params = $request->params;
 			$path = array('base' => $request->base, 'here' => $request->here);
 		}
@@ -854,7 +854,7 @@ class Router {
 		if (empty($url)) {
 			$output = isset($path['here']) ? $path['here'] : '/';
 			if ($full) {
-				$output = self::fullBaseUrl() . $output;
+				$output = static::fullBaseUrl() . $output;
 			}
 			return $output;
 		} elseif (is_array($url)) {
@@ -886,8 +886,8 @@ class Router {
 				}
 			}
 
-			$prefixExists = (array_intersect_key($url, array_flip(self::$_prefixes)));
-			foreach (self::$_prefixes as $prefix) {
+			$prefixExists = (array_intersect_key($url, array_flip(static::$_prefixes)));
+			foreach (static::$_prefixes as $prefix) {
 				if (!empty($params[$prefix]) && !$prefixExists) {
 					$url[$prefix] = true;
 				} elseif (isset($url[$prefix]) && !$url[$prefix]) {
@@ -902,7 +902,7 @@ class Router {
 
 			$match = false;
 
-			foreach (self::$routes as $route) {
+			foreach (static::$routes as $route) {
 				$originalUrl = $url;
 
 				$url = $route->persistParams($url, $params);
@@ -914,7 +914,7 @@ class Router {
 				$url = $originalUrl;
 			}
 			if ($match === false) {
-				$output = self::_handleNoRoute($url);
+				$output = static::_handleNoRoute($url);
 			}
 		} else {
 			if (preg_match('/^([a-z][a-z0-9.+\-]+:|:?\/\/|[#?])/i', $url)) {
@@ -923,7 +923,7 @@ class Router {
 			if (substr($url, 0, 1) === '/') {
 				$output = substr($url, 1);
 			} else {
-				foreach (self::$_prefixes as $prefix) {
+				foreach (static::$_prefixes as $prefix) {
 					if (isset($params[$prefix])) {
 						$output .= $prefix . '/';
 						break;
@@ -940,13 +940,13 @@ class Router {
 			$output = str_replace('//', '/', $base . '/' . $output);
 
 			if ($full) {
-				$output = self::fullBaseUrl() . $output;
+				$output = static::fullBaseUrl() . $output;
 			}
 			if (!empty($extension)) {
 				$output = rtrim($output, '/');
 			}
 		}
-		return $output . $extension . self::queryString($q, array(), $escape) . $frag;
+		return $output . $extension . static::queryString($q, array(), $escape) . $frag;
 	}
 
 /**
@@ -966,13 +966,13 @@ class Router {
  */
 	public static function fullBaseUrl($base = null) {
 		if ($base !== null) {
-			self::$_fullBaseUrl = $base;
+			static::$_fullBaseUrl = $base;
 			Configure::write('App.fullBaseUrl', $base);
 		}
-		if (empty(self::$_fullBaseUrl)) {
-			self::$_fullBaseUrl = Configure::read('App.fullBaseUrl');
+		if (empty(static::$_fullBaseUrl)) {
+			static::$_fullBaseUrl = Configure::read('App.fullBaseUrl');
 		}
-		return self::$_fullBaseUrl;
+		return static::$_fullBaseUrl;
 	}
 
 /**
@@ -987,7 +987,7 @@ class Router {
 		$named = $args = array();
 		$skip = array_merge(
 			array('bare', 'action', 'controller', 'plugin', 'prefix'),
-			self::$_prefixes
+			static::$_prefixes
 		);
 
 		$keys = array_values(array_diff(array_keys($url), $skip));
@@ -1002,7 +1002,7 @@ class Router {
 		}
 
 		list($args, $named) = array(Hash::filter($args), Hash::filter($named));
-		foreach (self::$_prefixes as $prefix) {
+		foreach (static::$_prefixes as $prefix) {
 			$prefixed = $prefix . '_';
 			if (!empty($url[$prefix]) && strpos($url['action'], $prefixed) === 0) {
 				$url['action'] = substr($url['action'], strlen($prefixed) * -1);
@@ -1020,7 +1020,7 @@ class Router {
 			array_unshift($urlOut, $url['plugin']);
 		}
 
-		foreach (self::$_prefixes as $prefix) {
+		foreach (static::$_prefixes as $prefix) {
 			if (isset($url[$prefix])) {
 				array_unshift($urlOut, $prefix);
 				break;
@@ -1037,10 +1037,10 @@ class Router {
 				if (is_array($value)) {
 					$flattend = Hash::flatten($value, '%5D%5B');
 					foreach ($flattend as $namedKey => $namedValue) {
-						$output .= '/' . $name . "%5B{$namedKey}%5D" . self::$_namedConfig['separator'] . rawurlencode($namedValue);
+						$output .= '/' . $name . "%5B{$namedKey}%5D" . static::$_namedConfig['separator'] . rawurlencode($namedValue);
 					}
 				} else {
-					$output .= '/' . $name . self::$_namedConfig['separator'] . rawurlencode($value);
+					$output .= '/' . $name . static::$_namedConfig['separator'] . rawurlencode($value);
 				}
 			}
 		}
@@ -1163,7 +1163,7 @@ class Router {
  * @return CakeRoute Matching route object.
  */
 	public static function requestRoute() {
-		return self::$_currentRoute[0];
+		return static::$_currentRoute[0];
 	}
 
 /**
@@ -1172,8 +1172,8 @@ class Router {
  * @return CakeRoute Matching route object.
  */
 	public static function currentRoute() {
-		$count = count(self::$_currentRoute) - 1;
-		return ($count >= 0) ? self::$_currentRoute[$count] : false;
+		$count = count(static::$_currentRoute) - 1;
+		return ($count >= 0) ? static::$_currentRoute[$count] : false;
 	}
 
 /**
@@ -1215,9 +1215,9 @@ class Router {
  * @see RequestHandler::startup()
  */
 	public static function parseExtensions() {
-		self::$_parseExtensions = true;
+		static::$_parseExtensions = true;
 		if (func_num_args() > 0) {
-			self::setExtensions(func_get_args(), false);
+			static::setExtensions(func_get_args(), false);
 		}
 	}
 
@@ -1230,11 +1230,11 @@ class Router {
  * @return array Array of extensions Router is configured to parse.
  */
 	public static function extensions() {
-		if (!self::$initialized) {
-			self::_loadRoutes();
+		if (!static::$initialized) {
+			static::_loadRoutes();
 		}
 
-		return self::$_validExtensions;
+		return static::$_validExtensions;
 	}
 
 /**
@@ -1248,12 +1248,12 @@ class Router {
  */
 	public static function setExtensions($extensions, $merge = true) {
 		if (!is_array($extensions)) {
-			return self::$_validExtensions;
+			return static::$_validExtensions;
 		}
 		if (!$merge) {
-			return self::$_validExtensions = $extensions;
+			return static::$_validExtensions = $extensions;
 		}
-		return self::$_validExtensions = array_merge(self::$_validExtensions, $extensions);
+		return static::$_validExtensions = array_merge(static::$_validExtensions, $extensions);
 	}
 
 /**
@@ -1262,7 +1262,7 @@ class Router {
  * @return void
  */
 	protected static function _loadRoutes() {
-		self::$initialized = true;
+		static::$initialized = true;
 		include APP . 'Config' . DS . 'routes.php';
 	}
 
