@@ -125,7 +125,7 @@ class TestAuthComponent extends AuthComponent {
 	}
 
 	public static function clearUser() {
-		self::$_user = array();
+		static::$_user = array();
 	}
 
 }
@@ -1282,14 +1282,47 @@ class AuthComponentTest extends CakeTestCase {
 
 		$this->Controller->response = $this->getMock('CakeResponse', array('_sendHeader'));
 		$this->Controller->response->expects($this->at(0))
-		->method('_sendHeader')
-		->with('HTTP/1.1 403 Forbidden', null);
+			->method('_sendHeader')
+			->with('HTTP/1.1 403 Forbidden', null);
+		$this->Auth->initialize($this->Controller);
+
+		ob_start();
+		$result = $this->Auth->startup($this->Controller);
+		ob_end_clean();
+
+		$this->assertFalse($result);
+		$this->assertEquals('this is the test element', $this->Controller->response->body());
+		$this->assertArrayNotHasKey('Location', $this->Controller->response->header());
+		$this->assertNull($this->Controller->testUrl, 'redirect() not called');
+		unset($_SERVER['HTTP_X_REQUESTED_WITH']);
+	}
+
+/**
+ * test ajax login with no element
+ *
+ * @return void
+ */
+	public function testAjaxLoginResponseCodeNoElement() {
+		$_SERVER['HTTP_X_REQUESTED_WITH'] = 'XMLHttpRequest';
+
+		$url = '/ajax_auth/add';
+		$this->Auth->request->addParams(Router::parse($url));
+		$this->Auth->request->query['url'] = ltrim($url, '/');
+		$this->Auth->request->base = '';
+		$this->Auth->ajaxLogin = false;
+
+		Router::setRequestInfo($this->Auth->request);
+
+		$this->Controller->response = $this->getMock('CakeResponse', array('_sendHeader'));
+		$this->Controller->response->expects($this->at(0))
+			->method('_sendHeader')
+			->with('HTTP/1.1 403 Forbidden', null);
 		$this->Auth->initialize($this->Controller);
 
 		$result = $this->Auth->startup($this->Controller);
 
-		$this->assertFalse($result);
-		$this->assertEquals('this is the test element', $this->Controller->response->body());
+		$this->assertArrayNotHasKey('Location', $this->Controller->response->header());
+		$this->assertNull($this->Controller->testUrl, 'redirect() not called');
 		unset($_SERVER['HTTP_X_REQUESTED_WITH']);
 	}
 
