@@ -373,7 +373,7 @@ class CakeResponseTest extends CakeTestCase {
  * @return void
  */
 	public function testCompress() {
-		if (php_sapi_name() !== 'cli') {
+		if (PHP_SAPI !== 'cli') {
 			$this->markTestSkipped('The response compression can only be tested in cli.');
 		}
 
@@ -491,7 +491,7 @@ class CakeResponseTest extends CakeTestCase {
 		if (!extension_loaded("zlib")) {
 			$this->markTestSkipped('Skipping further tests for outputCompressed as zlib extension is not loaded');
 		}
-		if (php_sapi_name() !== 'cli') {
+		if (PHP_SAPI !== 'cli') {
 			$this->markTestSkipped('Testing outputCompressed method with compression enabled done only in cli');
 		}
 
