@@ -300,6 +300,17 @@ class ControllerTestCaseTest extends CakeTestCase {
 		$this->assertSame(302, $Controller->response->statusCode());
 	}
 
+/**
+ * Test array URLs with testAction()
+ *
+ * @return void
+ */
+	public function testTestActionArrayUrls() {
+		$Controller = $this->Case->generate('TestsApps');
+		$this->Case->testAction(array('controller' => 'tests_apps', 'action' => 'index'));
+		$this->assertInternalType('array', $this->Case->controller->viewVars);
+	}
+
 /**
  * Test that file responses don't trigger errors.
  *
