@@ -41,7 +41,7 @@ class FolderTest extends CakeTestCase {
 
 		foreach (scandir(TMP) as $file) {
 			if (is_dir(TMP . $file) && !in_array($file, array('.', '..'))) {
-				self::$_tmp[] = $file;
+				static::$_tmp[] = $file;
 			}
 		}
 	}
@@ -62,7 +62,7 @@ class FolderTest extends CakeTestCase {
  * @return void
  */
 	public function tearDown() {
-		$exclude = array_merge(self::$_tmp, array('.', '..'));
+		$exclude = array_merge(static::$_tmp, array('.', '..'));
 		foreach (scandir(TMP) as $dir) {
 			if (is_dir(TMP . $dir) && !in_array($dir, $exclude)) {
 				$iterator = new RecursiveDirectoryIterator(TMP . $dir);
