@@ -1425,6 +1425,17 @@ class ViewTest extends CakeTestCase {
 		$this->assertSame('', $result);
 	}
 
+/**
+ * Test checking a block's existance.
+ *
+ * @return void
+ */
+	public function testBlockExist() {
+		$this->assertFalse($this->View->exists('test'));
+		$this->View->assign('test', 'Block content');
+		$this->assertTrue($this->View->exists('test'));
+	}
+
 /**
  * Test setting a block's content to null
  *
