@@ -115,15 +115,15 @@ class CakeText {
 		$offset = 0;
 		$buffer = '';
 		$results = array();
-		$length = strlen($data);
+		$length = mb_strlen($data);
 		$open = false;
 
 		while ($offset <= $length) {
 			$tmpOffset = -1;
 			$offsets = array(
-				strpos($data, $separator, $offset),
-				strpos($data, $leftBound, $offset),
-				strpos($data, $rightBound, $offset)
+				mb_strpos($data, $separator, $offset),
+				mb_strpos($data, $leftBound, $offset),
+				mb_strpos($data, $rightBound, $offset)
 			);
 			for ($i = 0; $i < 3; $i++) {
 				if ($offsets[$i] !== false && ($offsets[$i] < $tmpOffset || $tmpOffset == -1)) {
@@ -131,22 +131,23 @@ class CakeText {
 				}
 			}
 			if ($tmpOffset !== -1) {
-				$buffer .= substr($data, $offset, ($tmpOffset - $offset));
-				if (!$depth && $data{$tmpOffset} === $separator) {
+				$buffer .= mb_substr($data, $offset, ($tmpOffset - $offset));
+				$char = mb_substr($data, $tmpOffset, 1);
+				if (!$depth && $char === $separator) {
 					$results[] = $buffer;
 					$buffer = '';
 				} else {
-					$buffer .= $data{$tmpOffset};
+					$buffer .= $char;
 				}
 				if ($leftBound !== $rightBound) {
-					if ($data{$tmpOffset} === $leftBound) {
+					if ($char === $leftBound) {
 						$depth++;
 					}
-					if ($data{$tmpOffset} === $rightBound) {
+					if ($char === $rightBound) {
 						$depth--;
 					}
 				} else {
-					if ($data{$tmpOffset} === $leftBound) {
+					if ($char === $leftBound) {
 						if (!$open) {
 							$depth++;
 							$open = true;
@@ -157,7 +158,7 @@ class CakeText {
 				}
 				$offset = ++$tmpOffset;
 			} else {
-				$results[] = $buffer . substr($data, $offset);
+				$results[] = $buffer . mb_substr($data, $offset);
 				$offset = $length + 1;
 			}
 		}
@@ -331,7 +332,7 @@ class CakeText {
 		}
 		$options += array('width' => 72, 'wordWrap' => true, 'indent' => null, 'indentAt' => 0);
 		if ($options['wordWrap']) {
-			$wrapped = self::wordWrap($text, $options['width'], "\n");
+			$wrapped = static::wordWrap($text, $options['width'], "\n");
 		} else {
 			$wrapped = trim(chunk_split($text, $options['width'] - 1, "\n"));
 		}
@@ -357,7 +358,7 @@ class CakeText {
 	public static function wordWrap($text, $width = 72, $break = "\n", $cut = false) {
 		$paragraphs = explode($break, $text);
 		foreach ($paragraphs as &$paragraph) {
-			$paragraph = self::_wordWrap($paragraph, $width, $break, $cut);
+			$paragraph = static::_wordWrap($paragraph, $width, $break, $cut);
 		}
 		return implode($break, $paragraphs);
 	}
@@ -656,7 +657,7 @@ class CakeText {
  */
 	public static function excerpt($text, $phrase, $radius = 100, $ellipsis = '...') {
 		if (empty($text) || empty($phrase)) {
-			return self::truncate($text, $radius * 2, array('ellipsis' => $ellipsis));
+			return static::truncate($text, $radius * 2, array('ellipsis' => $ellipsis));
 		}
 
 		$append = $prepend = $ellipsis;
